(->delay remaining f)Create a delay which will execute a function in a specified number of frames.
Create a delay which will execute a function in a specified number of frames.
(add-delay {:keys [current-scene] :as state} d)Add a delay into the current scene.
Add a delay into the current scene.
(add-sprites-to-scene remaining new-sprites)Create a delay which adds new sprites to the current scene.
Create a delay which adds new sprites to the current scene.
(add-tween-to-sprites remaining tween sprite-selection-fn)Create a delay which adds a tween to the collection of sprites which
satisfy the sprite-selection-fn.
Create a delay which adds a tween to the collection of sprites which satisfy the `sprite-selection-fn`.
(apply-all state ds)Apply a sequence of delayed functions to the game state.
Apply a sequence of delayed functions to the game state.
(update-delay d)Decrement :remaining but stop at 0.
Decrement `:remaining` but stop at 0.
(update-delays {:keys [current-scene] :as state})Update all the delays in the current scene and apply the ones that have finished.
Update all the delays in the current scene and apply the ones that have finished.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |