Keyboard and mouse input handling.
Keyboard and mouse input handling.
(default-key-pressed state e)Prevent the default behaviour of esc closing the sketch and add the pressed key to the list of currently held keys.
Prevent the default behaviour of esc closing the sketch and add the pressed key to the list of currently held keys.
(default-key-released state e)Remove the released key from the list of currently held keys.
Remove the released key from the list of currently held keys.
(key-pressed {:keys [input-enabled? scenes current-scene] :as state} e)Reduce applying a handler function:
(f state e)
accross the collection of :key-pressed-fns in the current scene.
Reduce applying a handler function: (f state e) accross the collection of `:key-pressed-fns` in the current scene.
(key-released {:keys [input-enabled? scenes current-scene] :as state} e)Reduce applying a handler function:
(f state e)
accross the collection of :key-released-fns in the current scene.
Reduce applying a handler function: (f state e) accross the collection of `:key-released-fns` in the current scene.
(mouse-pressed {:keys [input-enabled? scenes current-scene] :as state} e)Reduce applying a handler function:
(f state e)
accross the collection of :mouse-pressed-fns in the current scene.
Reduce applying a handler function: (f state e) accross the collection of `:mouse-pressed-fns` in the current scene.
(mouse-released {:keys [input-enabled? scenes current-scene] :as state} e)Reduce applying a handler function:
(f state e)
accross the collection of :mouse-released-fns in the current scene.
Reduce applying a handler function: (f state e) accross the collection of `:mouse-released-fns` in the current scene.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |