(draw-scene-sprites {:keys [current-scene] :as state})Draw each sprite in the current scene using its :draw-fn.
Draw each sprite in the current scene using its `:draw-fn`.
(transition
{:keys [parent-update-fn parent-draw-fn] :as state}
target-scene
&
{:keys [transition-fn transition-length init-fn]
:or {transition-fn fade-to-black transition-length 20 init-fn identity}})Temporarily replace parent-update-fn and parent-draw-fn with
transition handdling versions which will set themselves back to the
originals on completion.
Temporarily replace `parent-update-fn` and `parent-draw-fn` with transition handdling versions which will set themselves back to the originals on completion.
(update-scene-sprites {:keys [current-scene] :as state})Update each sprite in the current scene using its :update-fn.
Update each sprite in the current scene using its `:update-fn`.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |