quip.sound

Music and sound effects.

There's no support for audio in Quil, so we're relying on interop with javax.sound.sampled.

Music and sound effects.

There's no support for audio in Quil, so we're relying on interop
with `javax.sound.sampled`.
raw docstring

*music*clj

source

close-line-on-end-listenerclj

source

get-lineclj

(get-line line-info mixer-info)
source

loop-musicclj

(loop-music track)
source

playclj

(play sound)
(play sound loop?)
source

stopclj

(stop clip)
source

stop-musicclj

(stop-music)
source

cljdoc builds & hosts documentation for Clojure/Script libraries