(->tween field
to-value
&
{:keys [from-value easing-fn update-fn step-count yoyo? yoyo-update-fn
on-yoyo-fn repeat-times on-repeat-fn on-complete-fn]
:or {yoyo? false
step-count 100
from-value 0
on-complete-fn identity
yoyo-update-fn -
easing-fn linear-easing-fn
update-fn +
on-repeat-fn identity
repeat-times 1
on-yoyo-fn identity}})Create a new tween for modifying a field on a sprite over time.
Create a new tween for modifying a field on a sprite over time.
(apply-tween sprite
{:keys [field update-fn yoyo? yoyoing? yoyo-update-fn total-change
normalized-deltas progress resetting?]})(update-tween {:keys [progress step-count yoyo? yoyoing? repeat-times]
:as tween})cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |